@@ -23,11 +23,14 @@
 #include "check_assertion.h"
 
 int main(int, char**) {
-    std::array<int, 3> array{0, 1, 2};
-    std::span<int> other(array.data(), 3);
+  std::array<int, 3> array{0, 1, 2};
+  std::span<int> other(array.data(), 3);
 
-    auto invalid_source = [&] { std::span<int, 2> const s(other); (void)s; };
-    TEST_LIBCPP_ASSERT_FAILURE(invalid_source(), "size mismatch in span's constructor (other span)");
+  auto invalid_source = [&] {
+    std::span<int, 2> const s(other);
+    (void)s;
+  };
+  TEST_LIBCPP_ASSERT_FAILURE(invalid_source(), "size mismatch in span's constructor (other span)");
 
-    return 0;
+  return 0;
 }
