@@ -6,6 +6,8 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: c++03, c++11
+
 // <map>
 
 // class multimap
@@ -16,21 +18,14 @@
 // equal_range shall not participate in overload resolution unless the
 // qualified-id Compare::is_transparent is valid and denotes a type
 
-
 #include <map>
 #include <cassert>
 
 #include "test_macros.h"
 #include "is_transparent.h"
 
-#if TEST_STD_VER <= 11
-#error "This test requires is C++14 (or later)"
-#else
+int main(int, char**) {
+  typedef std::multimap<int, double, transparent_less_private> M;
 
-int main(int, char**)
-{
-    typedef std::multimap<int, double, transparent_less_private> M;
-
-    TEST_IGNORE_NODISCARD M().count(C2Int{5});
+  TEST_IGNORE_NODISCARD M().count(C2Int{5});
 }
-#endif
